Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2010-04-28 11:25:39 +0400
committerCampbell Barton <ideasman42@gmail.com>2010-04-28 11:25:39 +0400
commit2d4d820b976b16c536af520378bdbd33d70b95b6 (patch)
tree02fc1a6ff0679f0398bfeafef253cd31ded78a37 /source/blender/editors/animation/anim_channels_defines.c
parent68e68af102a698d8b18cfb5326565346009a1ee7 (diff)
3dview --> view3d, patch by Jonathan Smith with small corrections and changes.
Diffstat (limited to 'source/blender/editors/animation/anim_channels_defines.c')
-rw-r--r--source/blender/editors/animation/anim_channels_defines.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/blender/editors/animation/anim_channels_defines.c b/source/blender/editors/animation/anim_channels_defines.c
index abd88052b9c..43a0c8de955 100644
--- a/source/blender/editors/animation/anim_channels_defines.c
+++ b/source/blender/editors/animation/anim_channels_defines.c
@@ -2334,8 +2334,8 @@ static void dummy_olddraw_gpencil ()
case SPACE_VIEW3D:
{
/* this shouldn't cause any overflow... */
- //sprintf(name, "3DView:%s", view3d_get_name(sa->spacedata.first)); // XXX missing func..
- strcpy(name, "3dView");
+ //sprintf(name, "View3D:%s", view3d_get_name(sa->spacedata.first)); // XXX missing func..
+ strcpy(name, "View3D");
special= ICON_VIEW3D;
}
break;